/* version.h: Part of GNU CSSC.
 *
 *  Copyright (C) 1997,2001,2007 Free Software Foundation, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *    
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *    
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
extern const char cssc_version[];
void show_config_info(void);
void show_copyright(void);

inline void
version() 
{
  fprintf(stderr, "%s\n", cssc_version);
  show_copyright();
  show_config_info();
}
